package com.ruoyi.web.controller.learn;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.learn.domain.LearnQuestionCorrect;
import com.ruoyi.learn.service.ILearnQuestionCorrectService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 题纠错Controller
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
@RestController
@RequestMapping("/learn/questionCorrect")
public class LearnQuestionCorrectController extends BaseController
{
    @Autowired
    private ILearnQuestionCorrectService learnQuestionCorrectService;

    /**
     * 查询题纠错列表
     */
    @PreAuthorize("@ss.hasPermi('learn:questionCorrect:list')")
    @GetMapping("/list")
    public TableDataInfo list(LearnQuestionCorrect learnQuestionCorrect)
    {
        startPage();
        List<LearnQuestionCorrect> list = learnQuestionCorrectService.selectLearnQuestionCorrectList(learnQuestionCorrect);
        return getDataTable(list);
    }

    /**
     * 导出题纠错列表
     */
    @PreAuthorize("@ss.hasPermi('learn:questionCorrect:export')")
    @Log(title = "题纠错", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LearnQuestionCorrect learnQuestionCorrect)
    {
        List<LearnQuestionCorrect> list = learnQuestionCorrectService.selectLearnQuestionCorrectList(learnQuestionCorrect);
        ExcelUtil<LearnQuestionCorrect> util = new ExcelUtil<LearnQuestionCorrect>(LearnQuestionCorrect.class);
        util.exportExcel(response, list, "题纠错数据");
    }

    /**
     * 获取题纠错详细信息
     */
    @PreAuthorize("@ss.hasPermi('learn:questionCorrect:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(learnQuestionCorrectService.selectLearnQuestionCorrectById(id));
    }

    /**
     * 新增题纠错
     */
    @PreAuthorize("@ss.hasPermi('learn:questionCorrect:add')")
    @Log(title = "题纠错", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LearnQuestionCorrect learnQuestionCorrect)
    {
        return toAjax(learnQuestionCorrectService.insertLearnQuestionCorrect(learnQuestionCorrect));
    }

    /**
     * 修改题纠错
     */
    @PreAuthorize("@ss.hasPermi('learn:questionCorrect:edit')")
    @Log(title = "题纠错", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LearnQuestionCorrect learnQuestionCorrect)
    {
        return toAjax(learnQuestionCorrectService.updateLearnQuestionCorrect(learnQuestionCorrect));
    }

    /**
     * 删除题纠错
     */
    @PreAuthorize("@ss.hasPermi('learn:questionCorrect:remove')")
    @Log(title = "题纠错", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(learnQuestionCorrectService.deleteLearnQuestionCorrectByIds(ids));
    }
}
